import React from 'react'
import { compose } from 'recompose'
import { connect } from 'react-redux'
import styled from 'styled-components'
import { actions } from 'pubsweet-client'
import { withJournal } from 'xpub-journal'
import { AppBar } from 'pubsweet-components-faraday/src/components'

const App = ({
  journal,
  children,
  logoutUser,
  currentUser,
  isAuthenticated,
}) => (
  <Root className="faraday-root">
    <AppBar
      brand={journal.metadata.name}
      isAuthenticated={isAuthenticated}
      onLogoutClick={logoutUser}
      user={currentUser}
    />
    <MainContainer className="faraday-main">{children}</MainContainer>
  </Root>
)

export default compose(
  connect(
    state => ({
      currentUser: state.currentUser.user,
      isAuthenticated: state.currentUser.isAuthenticated,
    }),
    { logoutUser: actions.logoutUser },
  ),
  withJournal,
)(App)

const Root = styled.div`
  font-family: ${props => props.theme.fontInterface};
  div[open] {
    width: auto;
  }
`

const MainContainer = styled.div`
  background-color: ${props => props.theme.backgroundColor || '#fff'};
  padding: 110px 10px 0 10px;
  min-height: 100vh;
`
